# Load csv data file
mydata = read.csv("RelativeAb_100_OTUs.csv")  # read csv file RelativeAb_5_OTUs.csv, RelativeAb_10_OTUs.csv, RelativeAb_30_OTUs.csv

# Set random seed to make results reproducible:
set.seed(23)

# Divide data into training and validation datasets
index=sample(2,nrow(mydata),replace=TRUE, prob=c(0.5,0.5))  
training <- mydata[index==1,]
validation <- mydata[index==2,]

# Import the randomForest package
library(randomForest)

# Perform training:
rf_classifier = randomForest(Group ~ ., data=training, ntree=300, mtry=33, importance=TRUE)
varImpPlot(rf_classifier, cex.lab=1.0)
rf_classifier

# Calculate prediction errors
prediction_for_table <- predict(rf_classifier,validation[,-101])
table(observed=validation[,101],predicted=prediction_for_table)

# Model tuning
tune.rf=tuneRF(mydata[,-15],mydata[,15],stepFactor=0.5)
print(tune.rf)

# Validation set assessment #2: ROC curves and AUC
# Import ROCR package for ROC curve plotting:
library(ROCR)

# Calculate the probability of new observations belonging to each class
# prediction_for_roc_curve will be a matrix with dimensions data_set_size x number_of_classes
prediction_for_roc_curve <- predict(rf_classifier,validation[,-101],type="prob")

# Set colours:
colours <- c("#304F88", "#AACC9C", "#992727",  "#A7A7A7", "#DA9924")

# Specify the different classes 
classes <- levels(validation$Group)
for (i in 1:5)
{
  # Define which observations belong to class[i]
  true_values <- ifelse(validation[,101]==classes[i],1,0)
  # Assess the performance of classifier for class[i]
  pred <- prediction(prediction_for_roc_curve[,i],true_values)
  perf <- performance(pred, "tpr", "fpr")
  if (i==1)
  {
    plot(perf,main="ROC Curve",lwd=3, cex.lab=1.5, cex.axis=1.5, col=colours[i]) 
  }
  else
  {
    plot(perf,main="ROC Curve",lwd=3, cex.lab=1.5, cex.axis=1.5, col=colours[i],add=TRUE) 
  }
  legend("bottomright", c("CG", "GC","HC", "IM", "IN"), lwd=3, lty=1, cex=1.5,col =colours)
  abline(a=0,b=1,lwd=2,lty=2,col="black")
  # Calculate the AUC and print it to screen
  auc.perf <- performance(pred, measure = "auc")
  print(classes[i])
  print(auc.perf@y.values)
}
#rf_classifier
